@@ -1,3 +1,4 @@
+import json
 from nb_log.set_nb_log_config import use_config_form_nb_log_config_module
 from nb_log import nb_log_config_default
 from nb_log.monkey_print import nb_print, patch_print, reverse_patch_print,stdout_write,stderr_write,print_raw,is_main_process,only_print_on_main_process
@@ -8,8 +9,8 @@ if nb_log_config_default.WARNING_PYCHARM_COLOR_SETINGS:
             """
             1)使用pycharm时候，强烈建议按下面的重新自定义设置pycharm的console里面的主题颜色，否则颜色显示瞎眼，代码里面规定的颜色只是大概的红黄蓝绿。在不同的ide软件和主题、字体下是不同的显示效果，需要用户自己设置。
             设置方式为 打开pycharm的 file -> settings -> Editor -> Color Scheme -> Console Colors 选择monokai，点击展开 ANSI colors，
-            并重新修改自定义6个颜色，设置Blue为 1585FF ，Cyan为 06B8B8 ，Green 为 05A53F ，Magenta为 ff1cd5,red为 FF0207 ，yellow为 FFB009 。
-            如果设置为显示背景色快，由于不同版本的pycahrm或主题，可以根据控制台实际显示设置 White 为 1F1F1F， Black 为 FFFFFF ，因为背景色是深色，前景色的文字设置为白色比黑色好。
+            并重新修改自定义6个颜色，设置Blue为 1585FF ，Cyan为 06B8B8 ，Green 为 05A53F ，Magenta为 ff1cd5 ,red为 FF0207 ，yellow为 FFB009  。
+            如果设置为显示背景色快，由于不同版本的pycahrm或主题，可以根据控制台实际显示设置 White 为 FFFFFF  ， Black 为 1F1F1F ，因为背景色是深色，前景色的文字设置为白色比黑色好。
             
             2)使用xshell或finashell工具连接linux也可以自定义主题颜色，默认使用shell连接工具的颜色也可以。
             
@@ -31,3 +32,4 @@ if nb_log_config_default.AUTO_PATCH_PRINT:
     patch_print()
 else:
     reverse_patch_print()
+
